@@ -21,7 +21,7 @@
 #define __SESSION_H__
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include <glib.h>
@@ -30,6 +30,7 @@
 #include <unistd.h>
 
 #include "socket.h"
+#include "proxy.h"
 
 #define SESSION_BUFFSIZE	4096
 
@@ -55,16 +56,6 @@ typedef enum {
 	SESSION_DISCONNECTED
 } SessionState;
 
-typedef enum
-{
-	SESSION_MSG_NORMAL,
-	SESSION_MSG_SEND_DATA,
-	SESSION_MSG_RECV_DATA,
-	SESSION_MSG_CONTROL,
-	SESSION_MSG_ERROR,
-	SESSION_MSG_UNKNOWN
-} SessionMsgType;
-
 typedef gint (*RecvMsgNotify)			(Session	*session,
 						 const gchar	*msg,
 						 gpointer	 user_data);
@@ -130,6 +121,8 @@ struct _Session
 	gint (*recv_msg)		(Session	*session,
 					 const gchar	*msg);
 
+	void (*connect_finished)	(Session	*session,
+					 gboolean	success);
 	gint (*send_data_finished)	(Session	*session,
 					 guint		 len);
 	gint (*recv_data_finished)	(Session	*session,
@@ -150,12 +143,23 @@ struct _Session
 	gpointer recv_data_notify_data;
 	gpointer send_data_progressive_notify_data;
 	gpointer send_data_notify_data;
-	
+
 	const void *account;
 	gboolean is_smtp;
+	gboolean ssl_cert_auto_accept;
+	gint ping_tag;
+
+	/* Pointer to ProxyInfo struct holding the info about proxy
+	 * to be used. Set to NULL if no proxy is used.
+	 * If non-NULL, the memory this pointer is pointing at does
+	 * not belong to this Session, and shouldn't be modified
+	 * or freed by Session. It is usually a pointer to the
+	 * SockInfo in common prefs, or in account prefs. */
+	ProxyInfo *proxy_info;
 
 #ifdef USE_GNUTLS
 	SSLType ssl_type;
+	gchar *gnutls_priority;
 #endif
 };
 
@@ -198,7 +202,6 @@ gint session_start_tls	(Session	*session);
 #endif
 
 gint session_send_msg	(Session	*session,
-			 SessionMsgType	 type,
 			 const gchar	*msg);
 gint session_recv_msg	(Session	*session);
 gint session_send_data	(Session	*session,
@@ -207,5 +210,6 @@ gint session_send_data	(Session	*session,
 gint session_recv_data	(Session	*session,
 			 guint		 size,
 			 const gchar	*terminator);
+void session_register_ping(Session *session, gboolean (*ping_cb)(gpointer data));
 
 #endif /* __SESSION_H__ */
